﻿// Insert portrait of author
// Copyright 2011 L'Express de Toronto Inc.
// Version 1.4
// Feb 10, 2011
// Written by Kasyan Servetsky
// http://www.kasyan.ho.com.ua
// e-mail: askoldich@yahoo.com
//==================================================================
if (app.documents.length == 0) ErrorExit("Please open a document and try again.");
// globals
var gSetFile, gText, gScenario;
var gScriptName = "Insert portrait of author";
var gScriptVersion = "1.4";
var gDoc = app.activeDocument;
var gSelection = gDoc.selection;

//~ var snippetsFolderPath = "~/Desktop/My Snippets/"; 
var snippetsFolderPath = "/Volumes/TEST/L'Express/Snippets/Portraits d'auteurs/";
var snippetsFolder = new Folder(snippetsFolderPath);
if (!snippetsFolder.exists) ErrorExit("Folder \"" + File.decode(snippetsFolder.name) + "\" doesn't exist.");

if (gSelection.length != 1) ErrorExit("One text frame or some text should be selected, or the cursor should be inserted into the text.");

if (gSelection[0].constructor.name == "TextFrame") { // a text frame is selected
	gText = gSelection[0].texts[0];
}
else if (gSelection[0].constructor.name == "InsertionPoint" || // some text is selected or the cursor is placed in the text
	gSelection[0].constructor.name == "Character" ||
	gSelection[0].constructor.name == "Word" ||
	gSelection[0].constructor.name == "TextStyleRange" ||
	gSelection[0].constructor.name == "Line" ||
	gSelection[0].constructor.name == "Paragraph" ||
	gSelection[0].constructor.name == "TextColumn" ||
	gSelection[0].constructor.name == "Text" ||
	gSelection[0].constructor.name == "TextFrame")
	{
		gText = gSelection[0].parentStory.texts[0];
	}
else if (gSelection[0].constructor.name == "Cell") { // a cell is selected
	gText = gSelection[0].parent.parent.parentStory.texts[0];
}
else if (gSelection[0].constructor.name == "Table") { // a table is selected
	gText = gSelection[0].parent.parentStory.texts[0];
}
else {
	ErrorExit("One text frame or some text should be selected, or the cursor should be inserted into the text.");
}
 
if (gText.contents == "") ErrorExit("The selection contains no text."); // text frame is empty

if (gText.constructor.name == "Text") {
	var gStory = gText.parentStory; // get the story
}
else {
	ErrorExit("Can't find the story.", true);
}

Main();

alert("Finished.", gScriptName + " - " + gScriptVersion);

//===================================== FUNCTIONS  ======================================
function Main() {
	app.findTextPreferences = app.changeTextPreferences = null;
	app.findTextPreferences.appliedParagraphStyle = gDoc.paragraphStyleGroups.item("Byline").paragraphStyles.item("Byline_auteur");
	var foundItems = gStory.findText();
	app.findTextPreferences = app.changeTextPreferences = null;
	
	if (foundItems.length > 0) {
		try {
			var authorPar = foundItems[0];
			var authorName = authorPar.contents.replace(/\r$/, ""); // remove return at the end
			var snippetFile = new File(snippetsFolderPath + authorName + ".idms");
			if (!snippetFile.exists) ErrorExit("File \"" + authorName + ".idms\"" + " has not been found in \"" + File.decode(snippetsFolder.name) + "\" folder.");
			
			var emailPar = gStory.paragraphs.nextItem(authorPar);
			if (emailPar == null || emailPar.appliedParagraphStyle != gDoc.paragraphStyleGroups.item("Byline").paragraphStyles.item("Byline_couriel")) ErrorExit("The author's name should be followed by \"Byline_couriel\"", true);
			var nextPar = gStory.paragraphs.nextItem(emailPar);
			
			if (nextPar.contents == "\r" && nextPar.appliedParagraphStyle != gDoc.paragraphStyles.item("zero leading")) { // if it's empty paragraph, apply "zero leading"
				var zeroLeadingPar = nextPar;
				zeroLeadingPar.appliedParagraphStyle = gDoc.paragraphStyles.item("zero leading");
			}
			if (nextPar.appliedParagraphStyle != gDoc.paragraphStyles.item("zero leading")) { // insert empty paragraph
				emailPar.insertionPoints[-1].contents = "\r";
				var zeroLeadingPar = gStory.paragraphs.nextItem(emailPar);
				zeroLeadingPar.appliedParagraphStyle = gDoc.paragraphStyles.item("zero leading");
			}
			else {
				var zeroLeadingPar = nextPar;
			}
			
			// remove the portrait if it already exists
			if (zeroLeadingPar.rectangles.length == 1) {
				try {
					zeroLeadingPar.rectangles[0].remove();
					if (gStory.paragraphs[2].appliedParagraphStyle == gDoc.paragraphStyles.item("zero leading")) gStory.paragraphs[2].remove();
					ErrorExit("The portrait of author has been removed.", false);
				}
				catch(err) {
					$.writeln(" 1 - zeroLeadingPar.rectangles[0].remove - " + err);
				}
			}
		
			nextPar.insertionPoints[0].place(snippetFile);
			var frame =  gStory.rectangles[0];
			with (frame.anchoredObjectSettings) {
				anchoredPosition = AnchorPosition.ANCHORED;
				spineRelative = false;
				lockPosition = false;
				pinPosition = true;
				anchorPoint = AnchorPoint.TOP_CENTER_ANCHOR;
				horizontalAlignment = HorizontalAlignment.CENTER_ALIGN;
				horizontalReferencePoint = AnchoredRelativeTo.COLUMN_EDGE;
				verticalAlignment = VerticalAlignment.CENTER_ALIGN;
				verticalReferencePoint = VerticallyRelativeTo.CAPHEIGHT;
				anchorXoffset = 0;
				anchorYoffset = 0.0625;
				anchorSpaceAbove = 0;
			}

		}
		catch(err) {
			$.writeln("2 - " + err);
		}
	}
	else {
		ErrorExit("The author's name has not been found in the text.");
	}
}
//--------------------------------------------------------------------------------------------------------------------------------------------------------
function ErrorExit(error, icon) {
	alert(error, gScriptName + " - " + gScriptVersion, icon);
	exit();
}
//--------------------------------------------------------------------------------------------------------------------------------------------------------